<?php

namespace Schaffen\Gef\Services;

use App\Http\Utils\SCHArray;
use Prettus\Validator\Exceptions\ValidatorException;
use Schaffen\Gef\Models\CategoriaGasto;
use Schaffen\Gef\Repositories\CategoriaGastoRepository;
use Schaffen\Gef\Validators\CategoriaGastoValidator;

class CategoriaGastoService
{

   private $repository;
   private $validator;

   public function __construct(CategoriaGastoRepository $repository, CategoriaGastoValidator $validator)
   {
      $this->repository = $repository;
      $this->validator = $validator;
   }

   public function updateOrCreate($data, $codigo = null)
   {
      try {

         $attrib = ['cag_codigo' => $codigo];

         $validator_rules = is_numeric($codigo) ? CategoriaGastoValidator::RULE_UPDATE : CategoriaGastoValidator::RULE_CREATE;
         $this->validator->with($data)->passesOrFail($validator_rules);
         $this->repository->setPresenter("Schaffen\\Gef\\Presenters\\CategoriaGastoPresenter");
         $data = SCHArray::addPrefix(CategoriaGasto::$prefix, $data);
         $categoria_gasto = $this->repository->updateOrCreate($attrib, $data);

         $response = [
            'status' => true,
            'errors' => '',
            'message' => 'Categoria(Gasto) gravado',
            'data' => $categoria_gasto['data'],
            'http_code' => '200'
         ];


         return $response;

      } catch (ValidatorException $e) {
         return $response = [
            'status' => false,
            'errors' => $e->getMessageBag(),
            'message' => 'Não foi possível gravar a Categoria(Gasto)',
            'data' => null,
            'http_code' => '400'
         ];
      }
   }
}
